==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectBranchalias.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectbranchalias_h
#define objectbranchalias_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_branchalias {
  t_adms _adms;
  p_module _module;
  int _module_isdefault : 1;
  char* _name;
  int _name_isdefault : 1;
  p_branch _branch;
  int _branch_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectBranch.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_branchalias_getuid (p_branchalias mybranchalias);
win32_interface gboolean adms_branchalias_cmp (p_branchalias mybranchalias,p_branchalias refbranchalias);
win32_interface p_branchalias adms_branchalias_new_1 (p_module mymodule,char* myname);
#define adms_branchalias_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_branchalias_free(item)\
{\
  free(item->_name);\
  free(item);\
}
win32_interface p_adms adms_branchalias_new_impl (p_adms arguments[]);
win32_interface p_branchalias adms_branchalias_impl (void* member);
#define adms_branchalias(member) ((p_branchalias) (member))
#define adms_branchalias_new adms_branchalias_new_1
#define adms_branchalias_isdefault_module(branchalias) (adms_branchalias(branchalias)->_module_isdefault)
#define adms_branchalias_valueof_module(branchalias) (adms_branchalias(branchalias)->_module)
#define adms_branchalias_isdefault_name(branchalias) (adms_branchalias(branchalias)->_name_isdefault)
#define adms_branchalias_valueof_name(branchalias) (adms_branchalias(branchalias)->_name)
#define adms_branchalias_isdefault_branch(branchalias) (adms_branchalias(branchalias)->_branch_isdefault)
#define adms_branchalias_valueof_branch(branchalias) (adms_branchalias(branchalias)->_branch)
#define adms_branchalias_valueof_adms(branchalias) ((p_adms)branchalias)
#define adms_branchalias_valueto_module(a,b) ((p_branchalias)a)->_module=(b)
win32_interface void adms_branchalias_valueto_module_impl (p_branchalias mybranchalias,p_module _module);
#define adms_branchalias_valueto_name(a,b) ((p_branchalias)a)->_name=(b)
win32_interface void adms_branchalias_valueto_name_impl (p_branchalias mybranchalias,char* _name);
#define adms_branchalias_valueto_branch(a,b) ((p_branchalias)a)->_branch=(b)
win32_interface void adms_branchalias_valueto_branch_impl (p_branchalias mybranchalias,p_branch _branch);
#endif /* objectbranchalias_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectBranchalias.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectbranchalias_h
#define objectbranchalias_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_branchalias {
  t_adms _adms;
  p_module _module;
  int _module_isdefault : 1;
  p_quark _name;
  int _name_isdefault : 1;
  p_branch _branch;
  int _branch_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectQuark.h>
#include <admsObject/objectBranch.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_branchalias_uid (p_branchalias mybranchalias);
win32_interface int adms_branchalias_cmp (p_branchalias mybranchalias,p_branchalias refbranchalias);
win32_interface p_branchalias adms_branchalias_new(p_module mymodule,p_quark myname);
win32_interface p_adms adms_branchalias_new_impl (p_adms arguments[]);
#define adms_branchalias(member) ((p_branchalias) (member))
#define adms_branchalias_isdefault_module(branchalias) (adms_branchalias(branchalias)->_module_isdefault)
#define adms_branchalias_valueof_module(branchalias) (adms_branchalias(branchalias)->_module)
#define adms_branchalias_isdefault_name(branchalias) (adms_branchalias(branchalias)->_name_isdefault)
#define adms_branchalias_valueof_name(branchalias) (adms_branchalias(branchalias)->_name)
#define adms_branchalias_isdefault_branch(branchalias) (adms_branchalias(branchalias)->_branch_isdefault)
#define adms_branchalias_valueof_branch(branchalias) (adms_branchalias(branchalias)->_branch)
#define adms_branchalias_valueof_adms(branchalias) ((p_adms)branchalias)
win32_interface inline void adms_branchalias_valueto_module (p_branchalias mybranchalias,p_module _module);
win32_interface inline void adms_branchalias_valueto_name (p_branchalias mybranchalias,p_quark _name);
win32_interface inline void adms_branchalias_valueto_branch (p_branchalias mybranchalias,p_branch _branch);
win32_interface inline void adms_branchalias_free(p_branchalias mybranchalias);
#endif /* objectbranchalias_h */
